@@ -14,6 +14,13 @@ from .models import DalleBartEncoder, DalleBartDecoder, VQGanDetokenizer
 torch.set_grad_enabled(False)
 torch.set_num_threads(os.cpu_count())
 
+torch.backends.cudnn.enabled = True
+torch.backends.cudnn.allow_tf32 = True
+torch.backends.cudnn.benchmark = True
+torch.backends.cudnn.deterministic = False
+torch.backends.cuda.matmul.allow_tf32 = True
+torch.backends.cuda.matmul.allow_fp16_reduced_precision_reduction = True
+
 MIN_DALLE_REPO = 'https://huggingface.co/kuprel/min-dalle/resolve/main/'
 
 
